@@ -39,7 +39,7 @@ class CausalTreeLearnNode(CausalTreeNode):
 class CausalTreeLearn(CausalTree):
 
     def __init__(self, weight=0.5, split_size=0.5, max_depth=-1, min_size=2, seed=724, feature_batch_size=None,
-                 magnitude=True, honest=False):
+                 magnitude=True, honest=False, max_values=None, verbose=False):
         super().__init__()
         self.weight = weight
         self.val_split = split_size
@@ -47,6 +47,9 @@ class CausalTreeLearn(CausalTree):
         self.min_size = min_size
         self.seed = seed
 
+        self.max_values = max_values
+        self.verbose = verbose
+
         self.max_effect = 0.0
         self.min_effect = 0.0
 
